==> naiveproxy-121.0.6167.71-1.tar.gz: naiveproxy-121.0.6167.71-1/src/net/log/net_log_source_type_list.h <==
// Copyright 2012 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// NOTE: No header guards are used, since this file is intended to be expanded
// directly within a block where the SOURCE_TYPE macro is defined.
// The following line silences a presubmit warning that would otherwise be
// triggered by this:
// no-include-guard-because-multiply-included
// NOLINT(build/header_guard)

// Used for global events which don't correspond to a particular entity.
SOURCE_TYPE(NONE)

SOURCE_TYPE(URL_REQUEST)
SOURCE_TYPE(PAC_FILE_DECIDER)
SOURCE_TYPE(HTTP_PROXY_CONNECT_JOB)
SOURCE_TYPE(SOCKS_CONNECT_JOB)
SOURCE_TYPE(SSL_CONNECT_JOB)
SOURCE_TYPE(TRANSPORT_CONNECT_JOB)
SOURCE_TYPE(SOCKET)
SOURCE_TYPE(HTTP2_SESSION)
SOURCE_TYPE(QUIC_CONNECTION_MIGRATION)
SOURCE_TYPE(QUIC_SESSION)
SOURCE_TYPE(HOST_RESOLVER_IMPL_JOB)
SOURCE_TYPE(DISK_CACHE_ENTRY)
SOURCE_TYPE(MEMORY_CACHE_ENTRY)
SOURCE_TYPE(HTTP_STREAM_JOB)
SOURCE_TYPE(EXPONENTIAL_BACKOFF_THROTTLING)
SOURCE_TYPE(UDP_SOCKET)
SOURCE_TYPE(CERT_VERIFY_PROC_CREATED)
SOURCE_TYPE(CERT_VERIFIER_JOB)
SOURCE_TYPE(CERT_VERIFIER_TASK)
SOURCE_TYPE(PROXY_CLIENT_SOCKET)
SOURCE_TYPE(BIDIRECTIONAL_STREAM)
SOURCE_TYPE(NETWORK_QUALITY_ESTIMATOR)
SOURCE_TYPE(HTTP_STREAM_JOB_CONTROLLER)
SOURCE_TYPE(CT_TREE_STATE_TRACKER)
SOURCE_TYPE(QUIC_STREAM_FACTORY_JOB)
SOURCE_TYPE(HTTP_SERVER_PROPERTIES)
SOURCE_TYPE(HOST_CACHE_PERSISTENCE_MANAGER)
SOURCE_TYPE(COOKIE_STORE)
SOURCE_TYPE(HTTP_AUTH_CONTROLLER)
SOURCE_TYPE(HTTP3_SESSION)
SOURCE_TYPE(WEB_TRANSPORT_CLIENT)
SOURCE_TYPE(NETWORK_SERVICE_HOST_RESOLVER)
SOURCE_TYPE(DNS_OVER_HTTPS)
SOURCE_TYPE(DNS_TRANSACTION)
SOURCE_TYPE(NETWORK_CHANGE_NOTIFIER)
SOURCE_TYPE(QUIC_STREAM_FACTORY)
SOURCE_TYPE(UDP_CLIENT_SOCKET)

==> naiveproxy-129.0.6668.81-2.tar.gz: naiveproxy-129.0.6668.81-2/src/net/log/net_log_source_type_list.h <==
// Copyright 2012 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// NOTE: No header guards are used, since this file is intended to be expanded
// directly within a block where the SOURCE_TYPE macro is defined.
// The following line silences a presubmit warning that would otherwise be
// triggered by this:
// no-include-guard-because-multiply-included
// NOLINT(build/header_guard)

// Used for global events which don't correspond to a particular entity.
SOURCE_TYPE(NONE)

SOURCE_TYPE(URL_REQUEST)
SOURCE_TYPE(PAC_FILE_DECIDER)
SOURCE_TYPE(HTTP_PROXY_CONNECT_JOB)
SOURCE_TYPE(SOCKS_CONNECT_JOB)
SOURCE_TYPE(SSL_CONNECT_JOB)
SOURCE_TYPE(TRANSPORT_CONNECT_JOB)
SOURCE_TYPE(TCP_STREAM_ATTEMPT)
SOURCE_TYPE(TLS_STREAM_ATTEMPT)
SOURCE_TYPE(SOCKET)
SOURCE_TYPE(HTTP2_SESSION)
SOURCE_TYPE(QUIC_CONNECTION_MIGRATION)
SOURCE_TYPE(QUIC_SESSION)
SOURCE_TYPE(HOST_RESOLVER_IMPL_JOB)
SOURCE_TYPE(DISK_CACHE_ENTRY)
SOURCE_TYPE(MEMORY_CACHE_ENTRY)
SOURCE_TYPE(HTTP_STREAM_JOB)
SOURCE_TYPE(HTTP_STREAM_POOL_GROUP)
SOURCE_TYPE(HTTP_STREAM_POOL_JOB)
SOURCE_TYPE(EXPONENTIAL_BACKOFF_THROTTLING)
SOURCE_TYPE(UDP_SOCKET)
SOURCE_TYPE(CERT_VERIFY_PROC_CREATED)
SOURCE_TYPE(CERT_VERIFIER_JOB)
SOURCE_TYPE(CERT_VERIFIER_TASK)
SOURCE_TYPE(PROXY_CLIENT_SOCKET)
SOURCE_TYPE(BIDIRECTIONAL_STREAM)
SOURCE_TYPE(NETWORK_QUALITY_ESTIMATOR)
SOURCE_TYPE(HTTP_STREAM_JOB_CONTROLLER)
SOURCE_TYPE(CT_TREE_STATE_TRACKER)
SOURCE_TYPE(QUIC_SESSION_POOL_DIRECT_JOB)
SOURCE_TYPE(QUIC_SESSION_POOL_PROXY_JOB)
SOURCE_TYPE(HTTP_SERVER_PROPERTIES)
SOURCE_TYPE(HOST_CACHE_PERSISTENCE_MANAGER)
SOURCE_TYPE(COOKIE_STORE)
SOURCE_TYPE(HTTP_AUTH_CONTROLLER)
SOURCE_TYPE(HTTP3_SESSION)
SOURCE_TYPE(WEB_TRANSPORT_CLIENT)
SOURCE_TYPE(NETWORK_SERVICE_HOST_RESOLVER)
SOURCE_TYPE(DNS_OVER_HTTPS)
SOURCE_TYPE(DNS_TRANSACTION)
SOURCE_TYPE(NETWORK_CHANGE_NOTIFIER)
SOURCE_TYPE(QUIC_SESSION_POOL)
SOURCE_TYPE(UDP_CLIENT_SOCKET)
SOURCE_TYPE(QUIC_PROXY_DATAGRAM_CLIENT_SOCKET)
